@@ -26,16 +26,21 @@ __tarball__ = """
   emptydir
   fhsmanpages
   fhsinfopages
+  filenames
   fileownership
   gnomemime
+  hardlinks
   hicoloricons
   infodirectory
+  kdeprograms
   libtool
   licensepkg
   lotsofdocs
   mimefiles
+  missingbackups
   perllocal
   permissions
+  rpath
   scrollkeeper
   symlink
   urlpkg
@@ -45,19 +50,30 @@ __tarball__ = """
 __pkgbuild__ = """
   arrays
   badbackups
-  capsnames
   carch
   checksums
   invalidstartdir
   license
   pkgname
-  rpath
+  pkgnameindesc
   sfurl
   tags
   url
 
 """.split()
 
-__all__ = __tarball__ + __pkgbuild__
+tarball_rules = {}
+for __rulename__ in __tarball__:
+	tarball_rules[__rulename__] = \
+		__import__("Namcap." + __rulename__, fromlist = "Namcap").package
+
+pkgbuild_rules = {}
+for __rulename__ in __pkgbuild__:
+	pkgbuild_rules[__rulename__] = \
+		__import__("Namcap." + __rulename__, fromlist = "Namcap").package
+
+all_rules = {}
+all_rules.update(tarball_rules)
+all_rules.update(pkgbuild_rules)
 
 # vim: set ts=4 sw=4 noet:
