@@ -1,4 +1,4 @@
-#! /usr/bin/env python
+#! /usr/bin/env python2
 # 
 # namcap - A Pacman package analyzer
 # Copyright (C) 2003-2009 Jason Chu <jason@archlinux.org>
@@ -26,15 +26,15 @@ import shutil
 sandbox_directory = '/tmp/namcap.' + str(os.getpid())
 
 # Functions
-# Return all possible modules (rules)
 def get_modules():
-	return Namcap.__all__
+	"""Return all possible modules (rules)"""
+	return Namcap.all_rules
 
-# Display usage information
 def usage():
-	print()
+	"""Display usage information"""
+	print("")
 	print("Usage: " + sys.argv[0] + " [OPTIONS] packages")
-	print()
+	print("")
 	print("Options are:")
 	print("    -i                               : prints information responses from rules")
 	print("    -m                               : makes the output parseable (machine-readable)")
@@ -43,8 +43,8 @@ def usage():
 
 	sys.exit(2)
 
-# Is the package a valid package file?
 def verify_package(filename):
+	"""Checks if a tarball is a valid package"""
 	if not os.path.isfile(filename):
 		return 0
 	if not tarfile.is_tarfile(filename):
@@ -95,6 +95,7 @@ def show_messages(name, key, messages):
 		print("%s %s: %s" % (name, key, m(msg[0]) % msg[1]))
 
 def process_realpackage(package, modules):
+	"""Runs namcap checks over a package tarball"""
 	extracted = 0
 	pkgtar = verify_package(package)
 
@@ -106,8 +107,7 @@ def process_realpackage(package, modules):
 
 	# Loop through each one, load them apply if possible
 	for i in modules:
-		cur_class = __import__('Namcap.' + i, globals(), locals(), [Namcap])
-		pkg = cur_class.package()
+		pkg = Namcap.all_rules[i]()
 		ret = [[], [], []]
 		if pkg.type() == "tarball":
 			if pkg.prereq() == "extract":
@@ -136,6 +136,7 @@ def process_realpackage(package, modules):
 		shutil.rmtree(sandbox_directory)
 
 def process_pkgbuild(package, modules):
+	"""Runs namcap checks over a PKGBUILD"""
 	# We might want to do some verifying in here... but really... isn't that what pacman.load is for?
 	pkginfo = pacman.load(package)
 
@@ -144,8 +145,7 @@ def process_pkgbuild(package, modules):
 		return 1
 
 	for i in modules:
-		cur_class = __import__('Namcap.' + i, globals(), locals(), [Namcap])
-		pkg = cur_class.package()
+		pkg = Namcap.all_rules[i]()
 		ret = [[], [], []]
 		if pkg.type() == "pkgbuild":
 			ret = pkg.analyze(pkginfo, package)
@@ -157,7 +157,6 @@ def process_pkgbuild(package, modules):
 		if info_reporting:
 			show_messages(name, 'I', ret[2])
 
-
 # Main
 modules = get_modules()
 info_reporting = 0
@@ -183,13 +182,13 @@ for i, k in optlist:
 		if k == 'list':
 			print("-"*20 + " Namcap rule list " + "-"*20)
 			for j in modules:
-				print(string.ljust(j, 20) + ": " + __import__('Namcap.' + j, globals(), locals(), [Namcap]).package().long_name())
+				print(string.ljust(j, 20) + ": " + modules[j]().long_name())
 			sys.exit(2)
 
 		module_list = k.split(',')
 		for j in module_list:
 			if j in modules:
-				active_modules.append(j)
+				active_modules[j] = modules[j]
 			else:
 				print("Error: Rule '" + j + "' does not exist")
 				usage()
@@ -197,10 +196,10 @@ for i, k in optlist:
 	# Used to exclude some rules from the check
 	if i in ('-e', '--exclude') and active_modules == []:
 		module_list = k.split(',')
-		active_modules = modules
+		active_modules.update(modules)
 		for j in module_list:
 			if j in modules:
-				active_modules.remove(j)
+				active_modules.pop(j)
 			else:
 				print("Error: Rule '" + j + "' does not exist")
 				usage()
